// Prevent "more" messages from appearing
set more off
// Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 4b               *******
*******             CHANGE "filesave" to your folder path                *******
********************************************************************************

// Defining global variable for file location to be replaced in code below
// \\Client\ precedes path in Virtual Desktop outside H drive;
global filesave "C:\Dropbox\23_PSQF6270\PSQF6270_Example4b"

// Import Houses XLSX data
import excel "$filesave\Houses.xlsx", firstrow case(preserve) clear 

// Categories for number of bedrooms 
gen bed3v2=.  
gen bed3v4=.
replace bed3v2=1 if beds==2
replace bed3v4=0 if beds==2
replace bed3v2=0 if beds==3
replace bed3v4=0 if beds==3
replace bed3v2=0 if beds==4
replace bed3v4=1 if beds==4
replace bed3v2=0 if beds==5
replace bed3v4=1 if beds==5
// Categories for number of bathrooms
gen bath2v1=. 
gen bath2v3=.
replace bath2v1=1 if baths==1 
replace bath2v3=0 if baths==1 
replace bath2v1=0 if baths==2 
replace bath2v3=0 if baths==2 
replace bath2v1=0 if baths==3 
replace bath2v3=1 if baths==3 
replace bath2v1=0 if baths==4 
replace bath2v3=1 if baths==4 
// Center and rescale size into per 100 square feet (0=1500)
gen sqft150=(size-1500)/100
// Generate quadratic sqft150 for use in some routines
gen sqft150sq=sqft150*sqft150
// Log-transform price for lognormal model
gen logprice=log(price)
// Label existing and new variables
label variable price    "price: Sale Price in 100,000 units"
label variable new      "new: House is new construction (0=no, 1=yes)"
label variable bed3v2   "bed3v2: 2 bedrooms instead of 3 (0=no, 1=yes)"
label variable bed3v4   "bed3v4: 4 bedrooms instead of 3 (0=no, 1=yes)"  
label variable bath2v1  "bath2v1: 1 bathroom instead of 2 (0=no, 1=yes)"
label variable bath2v3  "bath2v3: 3 bathrooms instead of 2 (0=no, 1=yes)"
label variable sqft150  "sqft150: Square Footage per 100 feet (0=1500)"
label variable logprice "logprice: Natural log of sale price in 100,000 units"


// Install user-written packages for gamma 
search lgamma // install from window


********************************************************************************
******                BEGIN EXAMPLE 4b CONTINUOUS MODELS                 *******
********************************************************************************

// Open external file to save results to
log using $filesave\PSQF6270_Example4b_STATA_Output.log, replace
 
display "STATA Distribution of Sale Price Outcome"
summarize price
hist price, percent start(0) width(20)
graph export "$filesave\STATA Price Histogram.png", replace
graph box price
graph export "$filesave\STATA Price Box Plot.png", replace

display "STATA Descriptive Stats for Example Variables"
summarize price size
tabulate beds
tabulate baths
tabulate new

display "STATA Predict Price using Identity Link, Normal Distribution" 
glm price c.new c.bed3v2 c.bed3v4 c.bath2v1 c.bath2v3 c.sqft150 ///
          c.sqft150#c.sqft150, ml link(identity) family(gaussian) nolog 
display "-2LL= " e(ll)*-2  // Print -2LL for model
test (c.new=0) (c.bed3v2=0) (c.bed3v4=0) (c.bath2v1=0) (c.bath2v3=0) ///
     (c.sqft150=0) (c.sqft150#c.sqft150=0) // Multiv Wald test of model
	 
display "STATA Predict Log-Transformed Price using Identity Link, Normal Distribution" 
glm logprice c.new c.bed3v2 c.bed3v4 c.bath2v1 c.bath2v3 c.sqft150 ///
             c.sqft150#c.sqft150, ml link(identity) family(gaussian) nolog
display "-2LL= "  e(ll)*-2  // Print -2LL for model
test (c.new=0) (c.bed3v2=0) (c.bed3v4=0) (c.bath2v1=0) (c.bath2v3=0) ///
     (c.sqft150=0) (c.sqft150#c.sqft150=0) // Multiv Wald test of model

// No Stata regression with a lognormal distribution that I could find
	 	 
display "STATA Predict Price using Log Link, Gamma Distribution" 
display "Using LGAMMA that does not allow factor variables or interactions"
display "GLM gives different LL and solution for gamma distribution"
lgamma price new bed3v2 bed3v4 bath2v1 bath2v3 sqft150 sqft150sq, nolog   
display "-2LL= " e(ll)*-2  // Print -2LL for model
test (new=0) (bed3v2=0) (bed3v4=0) (bath2v1=0) (bath2v3=0) ///
     (sqft150=0) (sqft150sq) // Multiv Wald test of model
	 
display "STATA LGAMMA: Price using Log Link, Gamma Distribution" 
display "Get Incident-Rate Ratios as exp(slope)"
lgamma price new bed3v2 bed3v4 bath2v1 bath2v3 sqft150 sqft150sq, eform nolog 


display "STATA Predict Price 50th Percentile (Median) using Quantile Regression"
set seed 8675309 // Set Jenny as random seed to get same results each time 
sqreg price c.new c.bed3v2 c.bed3v4 c.bath2v1 c.bath2v3 c.sqft150 ///
            c.sqft150#c.sqft150, quantile(.50) reps(500) nolog
test (c.new=0) (c.bed3v2=0) (c.bed3v4=0) (c.bath2v1=0) (c.bath2v3=0) ///
     (c.sqft150=0) (c.sqft150#c.sqft150=0) // Multiv Wald test of model does not match SAS
	 
display "STATA Predict Price 25th and 75th Percentile using Quantile Regression"
set seed 8675309 // Set Jenny as random seed to get same results each time 
sqreg price c.new c.bed3v2 c.bed3v4 c.bath2v1 c.bath2v3 c.sqft150 ///
            c.sqft150#c.sqft150, quantile(.25 .75) reps(500) nolog
// Multiv Wald test of model at 25th percentile
test ([q25]c.new=0) ([q25]c.bed3v2=0) ([q25]c.bed3v4=0) ([q25]c.bath2v1=0) ///
     ([q25]c.bath2v3=0)([q25]c.sqft150=0)([q25]c.sqft150#c.sqft150=0) 
// Multiv Wald test of model at 75th percentile
test ([q75]c.new=0) ([q75]c.bed3v2=0) ([q75]c.bed3v4=0) ([q75]c.bath2v1=0) ///
     ([q75]c.bath2v3=0)([q75]c.sqft150=0)([q75]c.sqft150#c.sqft150=0) 
// Multiv Wald test of difference in model between 25th and 75th percentile
test ([q25]c.new=[q75]c.new)([q25]c.bed3v2=[q75]c.bed3v2) ///
     ([q25]c.bed3v4=[q75]c.bed3v4)([q25]c.bath2v1=[q75]c.bath2v1) ///
     ([q25]c.bath2v3=[q75]c.bath2v3)([q25]c.sqft150=[q75]c.sqft150) ///
	 ([q25]c.sqft150#c.sqft150=[q75]c.sqft150#c.sqft150)
// How to test single slope diff across quantiles
test ([q25]c.new=[q75]c.new) 	

display "STATA Predict Price 25-75 Inter-Quantile Regression"
display "Output now directly provides predictor slope differences"
set seed 8675309 // Set Jenny as random seed to get same results each time 
iqreg price c.new c.bed3v2 c.bed3v4 c.bath2v1 c.bath2v3 c.sqft150 ///
            c.sqft150#c.sqft150, quantile(.25 .75) reps(500) nolog
test (c.new=0) (c.bed3v2=0) (c.bed3v4=0) (c.bath2v1=0) (c.bath2v3=0) ///
     (c.sqft150=0) (c.sqft150#c.sqft150=0) // Multiv Wald test of differences
	 
	 
// Close external file of saved results	
log close
